MethodChannelAppSecurityLock class

An implementation of AppSecurityLockPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({bool? isScreenLockEnabled, bool? isBackgroundLockEnabled, double? backgroundTimeout, bool? isTouchTimeoutEnabled, double? touchTimeout, bool? debug}) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUserInteraction() → void
用户交互时调用(主要用于Android平台)
inherited
restartTouchTimer() → void
重启触摸定时器
override
setBackgroundLockEnabled(bool enabled) → Future<void>
设置后台超时时间(秒)
override
setBackgroundTimeout(double timeoutSeconds) → Future<void>
更新后台锁定功能状态
override
setLockEnabled(bool enabled) → Future<void>
设置锁定状态
override
setOnAppLockedCallback(LockCallback? callback) → void
锁定回调(包含锁定原因)
override
setOnAppUnlockedCallback(VoidCallback? callback) → void
override
setOnEnterBackgroundCallback(VoidCallback? callback) → void
设置应用进入后台的回调
override
setOnEnterForegroundCallback(VoidCallback? callback) → void
设置应用进入前台的回调
override
setScreenLockEnabled(bool enabled) → Future<void>
更新屏幕锁定功能状态
override
setScreenRecordingProtectionEnabled(bool enabled, {String? warningMessage}) → Future<void>
启用/禁用截屏与录屏防护
override
setTouchTimeout(double timeoutSeconds) → Future<void>
设置触摸超时时间(秒)
override
setTouchTimeoutEnabled(bool enabled) → Future<void>
设置触摸超时启用状态
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited